@@ -1,6 +1,11 @@
 from .summarization import SummarizationMiddleware
 from .tool_selection import LLMToolSelectorMiddleware
-from .plan import PlanMiddleware, create_update_plan_tool, create_write_plan_tool
+from .plan import (
+    PlanMiddleware,
+    create_finish_sub_plan_tool,
+    create_read_plan_tool,
+    create_write_plan_tool,
+)
 from .model_fallback import ModelFallbackMiddleware
 from .tool_emulator import LLMToolEmulator
 
@@ -8,7 +13,8 @@ __all__ = [
     "SummarizationMiddleware",
     "LLMToolSelectorMiddleware",
     "PlanMiddleware",
-    "create_update_plan_tool",
+    "create_finish_sub_plan_tool",
+    "create_read_plan_tool",
     "create_write_plan_tool",
     "ModelFallbackMiddleware",
     "LLMToolEmulator",
